@@ -8,7 +8,7 @@ from zonis.exceptions import (
 
 # Closure codes can be between 3000-4999
 custom_close_codes: Dict[int, Type[BaseZonisException]] = {
-    3000: DuplicateConnection,
+    4102: DuplicateConnection,
     3001: UnhandledWebsocketType,
 }
 
@@ -16,9 +16,20 @@ custom_close_codes: Dict[int, Type[BaseZonisException]] = {
 class Packet(TypedDict):
     data: Any
     type: Literal["IDENTIFY", "REQUEST", "SUCCESS_RESPONSE", "FAILURE_RESPONSE"]
-    identifier: Optional[str]
+    identifier: str
 
 
 class RequestPacket(TypedDict):
     route: str
     arguments: Dict[str, Any]
+
+
+class IdentifyDataPacket(TypedDict):
+    override_key: Optional[str]
+    secret_key: str
+
+
+class IdentifyPacket(TypedDict):
+    identifier: str
+    type: Literal["IDENTIFY"]
+    data: IdentifyDataPacket
